powered by
You can combine one or more hypr objects, i.e. combine their hypothesis to a single hypr object, by adding them with the + or \* operators.
hypr
+
\*
# S4 method for hypr,hypr +(e1, e2)# S4 method for hypr,hypr *(e1, e2)# S4 method for hypr,hypr &(e1, e2)# S4 method for hypr,hypr /(e1, e2)
# S4 method for hypr,hypr *(e1, e2)
# S4 method for hypr,hypr &(e1, e2)
# S4 method for hypr,hypr /(e1, e2)
The combined hypr object
hypr objects to concatenate
*,hypr,hypr-method: Interaction of e1 and e2
*,hypr,hypr-method
e1
e2
&,hypr,hypr-method: Interaction and main contrasts of e1 and e2
&,hypr,hypr-method
/,hypr,hypr-method: Nesting levels of e2 within e1
/,hypr,hypr-method
(h1 <- hypr(a~i, b~i)) # a hypr object of two treatments (h2 <- hypr(i~0)) # an intercept-only hypr object hc <- h1 + h2 hc interaction <- h1 & h2 interaction_and_main <- h1 * h2
Run the code above in your browser using DataLab